import { NextPageContext } from 'next';

import Button from '@mui/material/Button';

import { NextGenThemeProvider } from '../components';
import { nuskinThemeTitleStyle } from './theme-builder';
import { FoundationTheme } from '../themes';
import styled from '@emotion/styled';
import { ColorUtils } from 'src/utils';

type HomePageProps = {
    theme?: FoundationTheme.Theme;
    themeName: string;
};

const buttonStyle = {
    marginBottom: '10px',
    marginLeft: 150
};

const ModeSwitchEnabledSection = styled.p`
    background: ${(props) => ColorUtils.paletteColor('primary')({ ...props, darkModeEnabled: true })};
    color: ${(props) => ColorUtils.paletteColor('primary', 'contrastText')({ ...props, darkModeEnabled: true })};
`;

const ModeSwitchDisabledSection = styled.p`
    background: ${(props) => ColorUtils.paletteColor('primary')({ ...props, darkModeEnabled: false })};
    color: ${(props) => ColorUtils.paletteColor('primary', 'contrastText')({ ...props, darkModeEnabled: false })};
`;

export default function Home({ theme, themeName }: HomePageProps) {
    const { palette = {}} = theme || {};
    const colorVariables = Object.keys(palette) as FoundationTheme.PaletteColors[];
    return (
        <NextGenThemeProvider cacheKey="nuskin-foundation-ui" theme={theme} isSSR>
            <h2 style={nuskinThemeTitleStyle}>
                {themeName === 'force-for-good' ? 'Force-For-Good-Button-Theme' : 'Nuskin-Button-Theme'}
            </h2>
            {colorVariables?.map((color) => (
                <div style={buttonStyle} key={color}>
                    <Button variant="contained" color={color}>
                        nuskin button
                    </Button>
                </div>
            ))}
            <div style={buttonStyle}>
                <div className="bg-accentColorA">
                    {' '}
                    Switch Colors using bg classnames like bg-primary, bg-accentColorA{' '}
                </div>
                <ModeSwitchEnabledSection className="text-white">Dark Mode Switch Enabled</ModeSwitchEnabledSection>
                <ModeSwitchDisabledSection className="text-white">Dark Mode Switch Disabled</ModeSwitchDisabledSection>
            </div>
        </NextGenThemeProvider>
    );
}

Home.getInitialProps = async (ctx: NextPageContext) => {
    const { query, req } = ctx || {};
    const themeName = query?.theme || 'nuskin-theme';
    let response;
    try {
        /*
         * [Todo] - Determine the environment in which the theme has to fetch the json
         */
        let config = await fetch(`http://${req?.headers.host}/${themeName}.json`);
        response = await config.json();
    } catch {
        console.warn('Theme Not found');
    }
    return {
        theme: response,
        themeName
    };
};
