
import startCase from 'lodash/startCase';

import { NextGenThemeProvider } from '../components';
import nuSkinTheme from '../themes/genome-foundation';
import { Divider } from '@mui/material';

export const nuskinThemeTitleStyle = {
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center'
};

const themeBoxStyles = {
    width: '150px',
    height: '150px',
    borderRadius: '10px',
    border: '1px solid black'
};

const defaultPalette = nuSkinTheme?.palette || {};

export default function ThemeBuilder() {
    return (
        <NextGenThemeProvider cacheKey="nuskin-foundation-ui" isSSR>
            <div style={{ background: '#FFF' }}>
                <h2 style={nuskinThemeTitleStyle}>Nuskin-Color-Theme</h2>
                {Object.entries(defaultPalette)?.map(renderPalette)}
            </div>
        </NextGenThemeProvider>
    );
}

const renderPalette = (color: any[]) => {
    const [colorKey, colorValue] = color;
    return (
        <div style={{ marginLeft: 200 }} key={colorKey}>
            <h2>{startCase(colorKey)}</h2>
            <div style={{ display: 'flex', gap: '10px' }}>
                <div>
                    <div style={{ ...themeBoxStyles, background: colorValue?.main }} />
                    <p>Main - {colorValue?.main}</p>
                </div>
                <div>
                    <div style={{ ...themeBoxStyles, background: colorValue?.contrastText }} />
                    <p>Contrast - {colorValue?.contrastText}</p>
                </div>
            </div>
            <h3> Button States </h3>
            <div style={{ display: 'flex', gap: '10px' }}>
                {Object.entries(colorValue?.buttonState || {})?.map(renderButtonState)}
            </div>
            <Divider />
        </div>
    );
};

const renderButtonState = (colorVariety: any[]) => {
    const [colorVariety0, colorVariety1] = colorVariety;
    if (typeof colorVariety1 !== 'string') return null;
    return (
        <div key={colorVariety0}>
            <p style={{ marginTop: '15px' }}> {colorVariety0 || ''}</p>
            <div
                style={{
                    ...themeBoxStyles,
                    background: colorVariety1 || 'black',
                }}
            />
            <p style={{ marginTop: '15px' }}> {colorVariety1 || ''}</p>
        </div>
    );
};
