/* eslint-disable no-unused-vars */
import { Palette } from '@mui/material/styles';

import { ComponentConfig } from './types';

export { default as nuskinTheme } from './genome-foundation';
export { default as forceForGoodTheme } from './force-for-good';

export const PaletteColors = [
    'primary',
    'neutral',
    'accentColorA',
    'accentColorB',
    'accentColorC' ,
    'accentColorD',
    'secondary',
    'success',
    'warning',
    'error',
    'info',
] as const;

export const AppColorGroups = [
    ...PaletteColors,
    'custom',
] as const; 

export namespace FoundationTheme {

    export type Mode = 'light' | 'dark';

    export type HexColor = `#${string}`;

    export type CommonColors = {
        white: string;
        black: string;
    }

    type ColorGroupPrimary = {
        primary? : {
            black: HexColor;
            white: HexColor;
            gray: HexColor;
            dark: HexColor;
        }
    } 
    
    export type PaletteColors = typeof PaletteColors[number];

    export type AppColors = typeof AppColorGroups[number];
    
    export type Colors = {
        [paletteColor in AppColors]?: {
            [colorId: string]: string | { main: string, dark?: string };
        } & ColorGroupPrimary;
    };

    export interface ButtonState {
        hovered?: string;
        hoveredText?: string;
        pressed?: string;
        pressedText?: string;
        focused?: string;
        focusedText?: string;
        disabled?: string;
        disabledText?: string;
    }

    export type PaletteColorType = {
        main: string;
        contrastText: string;
        buttonState?: ButtonState;
        darkMode?: {
            main: string;
            contrastText: string;
            buttonState?: ButtonState;
        }
    };

    export type ThemeConfig = {
        components?: ComponentConfig;
    }

    export type Theme = {
        palette?: Palette;
        colors?: Colors;
        config?: ThemeConfig;
    };

}