/* eslint-disable no-unused-vars */

import '@mui/material/styles';
import '@mui/material/Typography';
import '@mui/material/Button';
import { CSSProperties } from 'react';

import { Colors, FoundationTheme } from './themes';
import {
    Palette,
    PaletteColorOptions,
    CommonColors,
    PaletteTonalOffset,
    TypeText,
    TypeDivider,
    TypeAction,
    TypeBackground,
    PaletteAugmentColorOptions,
} from '@mui/material/styles/createPalette';

declare module '@emotion/react' {
  export interface Theme {
    palette: Palette;
    colors?: FoundationTheme.Colors;
    config?: FoundationTheme.ThemeConfig;
  }

}

declare module '@mui/material/styles' {

    interface Theme {
        colors?: FoundationTheme.Colors;
        config?: FoundationTheme.ThemeConfig;
    }

    interface PaletteColor {
        dark?: PaletteOptions;
        light?: PaletteOptions;
        buttonState?: FoundationTheme.ButtonState;
        darkMode?: Palette['primary'] & FoundationTheme.ButtonState;
    }

    interface Palette {
        primary: PaletteColor;
        neutral?: PaletteColor;
        secondary?: PaletteColor;
        accentColorA?: PaletteColor;
        accentColorB?: PaletteColor;
        accentColorC?: PaletteColor;
        accentColorD?: PaletteColor;
        success?: PaletteColor;
        warning?: PaletteColor;
        error?: PaletteColor;
        info?: PaletteColor;
        contrastThreshold?: number;
        tonalOffset?: number;
        common?: CommonColors;
        mode?: FoundationTheme.Theme;
        contrastThreshold?: number;
        tonalOffset?: PaletteTonalOffset;
        grey?: PaletteColor;
        text?: TypeText;
        divider?: TypeDivider;
        action?: TypeAction;
        background?: TypeBackground;
        getContrastText?: (background: string) => string;
        augmentColor?: (options: PaletteAugmentColorOptions) => PaletteColor;
    }

    interface PaletteOptions {
        neutral?: PaletteColor;
        secondary?: PaletteColor;
        accentColorA?: PaletteColor;
        accentColorB?: PaletteColor;
        accentColorC?: PaletteColor;
        accentColorD?: PaletteColor;
        success?: PaletteColor;
        warning?: PaletteColor;
        error?: PaletteColor;
        info?: PaletteColor;
    }

}

declare module '@mui/material/Button' {
  // Update the Button's color prop options
  interface ButtonPropsColorOverrides {
    neutral: true;
    accentColorA: true;
    accentColorB: true;
    accentColorC: true;
    accentColorD: true;
    inherit: false;
  }
}
